@@ -200,7 +200,22 @@ class Catalog extends database_object {
 		$results 		= array_merge(self::count_video($catalog_id),$results); 
 
 		$hours = floor($results['time']/3600);
-		$size = $results['size']/1048576;
+                // Calculate catalog size in bytes, divided by 1000
+                // We do so by first chopping the three least significant decimal digits off
+                // This is needed in case catalog size exceeds 4 GB ( 2 << 31)
+                // The precision lost here is not important, because during
+                // presentation we do not care about less than 0.01 MB.
+                //
+                $sizeStr = (string)$results['size'];
+                if ( strlen( $sizeStr ) > 3 ) {
+			$size = (int)substr( $sizeStr, 0, -3 );
+                }
+                else {
+			$size = 0;
+                }
+                // Now go to MB's, applying a correction for KB first.
+                //
+                $size = ($size / 1.024) / 1024;
 		$days = floor($hours/24);
 		$hours = $hours%24;
 
@@ -330,6 +345,12 @@ class Catalog extends database_object {
 			$this->get_album_art('',1);
 		}
 
+		if ($options['parse_m3u'] AND count($this->_playlists)) { 
+			foreach ($this->_playlists as $playlist_file) { 
+				$result = $this->import_m3u($playlist_file); 
+			} 
+		} // if we need to do some m3u-age
+
 		return true;
 
 	} // run_add
@@ -603,7 +624,6 @@ class Catalog extends database_object {
 			flush();
 		}
 
-
 		/* Close the dir handle */
 		@closedir($handle);
 
