@@ -32,6 +32,7 @@ $ajax_url = Config::get('ajax_url');
   <col id="col_artist" />
   <col id="col_songs" />
   <col id="col_year" />
+  <col id="col_tags" />
   <col id="col_rating" />
   <col id="col_action" />
 </colgroup>
@@ -40,14 +41,18 @@ $ajax_url = Config::get('ajax_url');
 	<?php if (Browse::get_filter('show_art')) { ?>
 	<th class="cel_cover"><?php echo _('Cover'); ?></th>
 	<?php } ?>
-	<th class="cel_album"><?php echo Ajax::text('?page=browse&action=set_sort&sort=name',_('Album'),'album_sort_name'); ?></th>
-	<th class="cel_artist"><?php echo _('Artist'); ?></th>
+	<th class="cel_album"><?php echo Ajax::text('?page=browse&action=set_sort&type=album&sort=name',_('Album'),'album_sort_name'); ?></th>
+	<th class="cel_artist"><?php echo Ajax::text('?page=browse&action=set_sort&type=album&sort=artist',_('Artist'),'album_sort_artist'); ?></th>
 	<th class="cel_songs"><?php echo _('Songs'); ?></th>
-	<th class="cel_year"><?php echo Ajax::text('?page=browse&action=set_sort&sort=year',_('Year'),'album_sort_year'); ?></th>
+	<th class="cel_year"><?php echo Ajax::text('?page=browse&action=set_sort&type=album&sort=year',_('Year'),'album_sort_year'); ?></th>
+	<th class="cel_tags"><?php echo _('Tags'); ?></th>
 	<th class="col_rating"><?php echo _('Rating'); ?></th>
 	<th class="cel_action"><?php echo _('Actions'); ?></th>
 </tr>
 <?php 
+	if (Config::get('ratings')) { 
+		Rating::build_cache('album',$object_ids); 
+	} 
 	/* Foreach through the albums */
 	foreach ($object_ids as $album_id) { 
 		$album = new Album($album_id); 
@@ -67,10 +72,11 @@ $ajax_url = Config::get('ajax_url');
 	<?php if (Browse::get_filter('show_art')) { ?>
 	<th class="cel_cover"><?php echo _('Cover'); ?></th>
 	<?php } ?>
-	<th class="cel_album"><?php echo Ajax::text('?page=browse&action=set_sort&sort=name',_('Album'),'album_sort_name_bottom'); ?></th>
+	<th class="cel_album"><?php echo Ajax::text('?page=browse&action=set_sort&type=album&sort=name',_('Album'),'album_sort_name_bottom'); ?></th>
 	<th class="cel_artist"><?php echo _('Artist'); ?></th>
 	<th class="cel_songs"><?php echo _('Songs'); ?></th>
-	<th class="cel_year"><?php echo Ajax::text('?page=browse&action=set_sort&sort=year',_('Year'),'album_sort_year_bottom'); ?></th>
+	<th class="cel_year"><?php echo Ajax::text('?page=browse&action=set_sort&type=album&sort=year',_('Year'),'album_sort_year_bottom'); ?></th>
+	<th class="cel_tags"><?php echo _('Tags'); ?></th>
 	<th class="col_rating"><?php echo _('Rating'); ?></th>
 	<th class="cel_action"><?php echo _('Actions'); ?></th>
 </tr>
