@@ -19,12 +19,19 @@
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 if (INSTALL != '1') { exit; } 
+
+// Set defaults for the form, if they've already submited something 
+$local_db = $_POST['local_db'] ? scrub_in($_POST['local_db']) : 'ampache'; 
+$local_host = $_POST['local_host'] ? scrub_in($_POST['local_host']) : 'localhost'; 
+$local_username = $_POST['local_username'] ? scrub_in($_POST['local_username']) : 'root'; 
+
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $htmllang; ?>" lang="<?php echo $htmllang; ?>">
 <head>
 <title>Ampache :: For The Love Of Music - Install</title>
 <link rel="stylesheet" href="templates/install.css" type="text/css" media="screen" />
+<meta http-equiv="Content-Type" content="text/html; Charset=<?php echo $charset; ?>" />
 </head>
 <body>
 <script src="lib/javascript-base.js" language="javascript" type="text/javascript"></script>
@@ -35,7 +42,7 @@ if (INSTALL != '1') { exit; }
 <div id="text-box">
 
 	<div class="notify">
-		<b><?php echo _('Requirements'); ?></b>
+		<h3><?php echo _('Requirements'); ?></h3>
 		<p>
 		<?php echo _("This Page handles the installation of the Ampache database and the creation of the ampache.cfg.php file. Before you continue please make sure that you have the following pre-requisites"); ?>
 		</p>
@@ -49,7 +56,7 @@ if (INSTALL != '1') { exit; }
 	</div>
 	
 	<div class="content">
-		<b><?php echo _("Step 1 - Creating and Inserting the Ampache Database"); ?></b><br />
+		<strong><?php echo _("Step 1 - Creating and Inserting the Ampache Database"); ?></strong><br />
 		<dl>
 			<dd><?php echo _("This step creates and inserts the Ampache database, as such please provide a mysql account with database creation rights. This step may take a while depending upon the speed of your computer"); ?></dd>
 		</dl>
@@ -63,15 +70,15 @@ if (INSTALL != '1') { exit; }
 <table>
 <tr>
 	<td class="align"><?php echo _("Desired Database Name"); ?></td>
-	<td><input type="text" name="local_db" value="ampache" /></td>
+	<td><input type="text" name="local_db" value="<?php echo scrub_out($local_db); ?>" /></td>
 </tr>
 <tr>
 	<td class="align"><?php echo _("MySQL Hostname"); ?></td>
-	<td><input type="text" name="local_host" value="localhost" /></td>
+	<td><input type="text" name="local_host" value="<?php echo scrub_out($local_host); ?>" /></td>
 </tr>
 <tr>
 	<td class="align"><?php echo _("MySQL Administrative Username"); ?></td>
-	<td><input type="text" name="local_username" value="root" /></td>
+	<td><input type="text" name="local_username" value="<?php echo scrub_out($local_username); ?>" /></td>
 </tr>
 <tr>
 	<td class="align"><?php echo _("MySQL Administrative Password"); ?></td>
@@ -107,7 +114,7 @@ if (INSTALL != '1') { exit; }
 		
 	</div>
 	<div id="bottom">
-    	<p><b>Ampache Installation.</b><br />
+    	<p><strong>Ampache Installation.</strong><br />
     	Pour l'Amour de la Musique</p>
    </div>
 </div>
